==> stoq-1.5.0.tar.gz: stoq-1.5.0/stoqlib/gui/test/test_taxclasssearch.py <==
# -*- coding: utf-8 -*-
# vi:si:et:sw=4:sts=4:ts=4

##
## Copyright (C) 2012 Async Open Source <http://www.async.com.br>
## All rights reserved
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., or visit: http://www.gnu.org/.
##
## Author(s): Stoq Team <stoq-devel@async.com.br>
##

from stoqlib.domain.taxes import ProductTaxTemplate
from stoqlib.gui.search.taxclasssearch import TaxTemplatesSearch
from stoqlib.gui.uitestutils import GUITest


class TestTaxClassSearch(GUITest):
    def testSearch(self):
        ProductTaxTemplate(name=u'Test ICMS Tax Template',
                           tax_type=ProductTaxTemplate.TYPE_ICMS,
                           connection=self.trans)
        ProductTaxTemplate(name=u'Test IPI Tax Template',
                           tax_type=ProductTaxTemplate.TYPE_IPI,
                           connection=self.trans)

        search = TaxTemplatesSearch(self.trans)

        search.search.refresh()
        self.check_search(search, 'product-tax-template')

==> stoq-1.6.0.tar.gz: stoq-1.6.0/stoqlib/gui/test/test_taxclasssearch.py <==
# -*- coding: utf-8 -*-
# vi:si:et:sw=4:sts=4:ts=4

##
## Copyright (C) 2012 Async Open Source <http://www.async.com.br>
## All rights reserved
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., or visit: http://www.gnu.org/.
##
## Author(s): Stoq Team <stoq-devel@async.com.br>
##

from stoqlib.domain.taxes import ProductTaxTemplate
from stoqlib.gui.search.taxclasssearch import TaxTemplatesSearch
from stoqlib.gui.uitestutils import GUITest


class TestTaxClassSearch(GUITest):
    def testSearch(self):
        ProductTaxTemplate(name=u'Test ICMS Tax Template',
                           tax_type=ProductTaxTemplate.TYPE_ICMS,
                           store=self.store)
        ProductTaxTemplate(name=u'Test IPI Tax Template',
                           tax_type=ProductTaxTemplate.TYPE_IPI,
                           store=self.store)

        search = TaxTemplatesSearch(self.store)

        search.search.refresh()
        self.check_search(search, 'product-tax-template')
